from django.shortcuts import render
from django.views.generic import DetailView

from hexia_pages.models import Page
# Create your views here.

class PageView (DetailView):
    model = Page
    #template_name = 'hexia_pages/page.html'


from django.contrib import admin

from hexia_pages.models import Page

# Register your models here.

class PageAdmin(admin.ModelAdmin):
    list_display = ['name']
    ordering = ['name',]
    readonly_fields = ['slug']

    def get_actions(self, request):
        actions = super(PageAdmin, self).get_actions(request)
        if 'delete_selected' in actions:
            del actions['delete_selected']
        return actions
    
    def has_delete_permission(self, request, obj=None):
        return False

    def has_add_permission(self, request):
        return False
        
admin.site.register(Page, PageAdmin)


from django.core.management.base import BaseCommand, CommandError
from django.conf import settings
from django.utils.text import slugify

from hexia_pages.models import Page

pages = settings.HEXIA_PAGES_LIST

class Command(BaseCommand):
    help = 'Sets Up initial hexia_pages data'

    def handle(self, *args, **options):
        for p in settings.HEXIA_PAGES_LIST:
            p, created = Page.objects.get_or_create (
                name = p[0],
                slug = p[1])
            p.save()


from django.db import models

from ckeditor_uploader.fields import RichTextUploadingField

# Create your models here.

class Page (models.Model):
    ''' Defines a Page shown through a template '''
    name = models.CharField(
        max_length=20
    )
    slug = models.SlugField(
        unique = True,
    )
    content = RichTextUploadingField()
    
    def __str__(self):
        return u'%s' % (self.name)

    class Meta:
        ordering = ['name']